package com.siemag.test.utils;

import static org.testng.AssertJUnit.*;

import javax.inject.Inject;
import javax.transaction.UserTransaction;

import org.apache.log4j.Logger;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;



/**
 * For common use for all Integration tests which running in cointainer. Use also only local interfaces here . <br>
 * Inject all common needed DAOS and methods which assert the manipulated {@link EditableIF}<br>
 * All inherited tests don't need start a Transaction. This class will start and try commit for every testmethod automatically.
 * @author huso
 */

public class AbstractTestMasterLocal extends AbstractTestMaster {

  private static int        beginCount  = 0;
  private static int        commitCount = 0;
//  //  @Inject
  /**
   * In some cases the DI is not happend in @BeforeXXX and @AfterXXX methods. So be sure that we can log in every case. 
   */
  private Logger            log         = Logger.getLogger(getClass());

  @Inject
  protected UserTransaction utx;

  @BeforeMethod
  public void beginTransaction(){
    if (isRunningInContainer()) {
      // Should start transaction
      System.out.println("AbstractTestMasterLocal.beginTransaction()");
      log.info("###### START UTX   ############");
      assertNotNull(utx);
    }
  }

  @AfterMethod
  public void commitTransaction(){
    if (isRunningInContainer()) {
      // Should stop transaction
      System.out.println("AbstractTestMasterLocal.commitTransaction()");
      log.info("###### STOP UTX   ############");
      assertNotNull(utx);
    }
  }

  protected final void startWMS(){
    try {
      System.out.println("AbstractTestMasterLocal.startWMS()");
      fail("FAKE FAIL startWMS");
      log.error("---------------------- END  --------------------------------");
    } catch (Exception e) {
      log.error("", e);
      fail("WMS can not be start");
    }

  }

  protected final void stopWMS(){
    try {
      System.out.println("AbstractTestMasterLocal.stopWMS()");
      fail("FAKE FAIL stopWMS");
    } catch (Exception e) {
      log.error("", e);
      fail("WMS can not be start");
    }
  }

  @Test
  public void checkInjections(){
    log.info("Dependency Injection of Services OK ");
    assertNotNull(utx);
  }
  @Test
  public void letsFail(){
    System.out.println("AbstractTestMasterLocal.letsFail()");
    assertNotNull(null);
  }

}
